Superintendencia de Servicios de Salud

0800 222 SALUD (72583)
Menu
Usuario: USERTEST | HOSPITAL MILITAR | SALIR

### Consultas al Padrón de Beneficiarios de los Agentes Nacionales del Seguro de Salud

Sr. beneficiario

A través de esta página Ud. podrá acceder a los datos de los beneficiarios titulares y familiares a cargo incluidos en la Base de Datos del Padrón de afiliados que actualiza esta Superintendencia con los datos aportados por cada uno de los Agentes del Seguro de Salud con carácter de declaración jurada. Para ello deberá conocer previamente el número de CUIL o el Documento de Identidad de la persona buscada.
Como resultado de la búsqueda obtendrá datos identificatorios del beneficiario y la Obra Social en la que se encuentra afiliado.
CUIL
Ingrese un CUIL con el formato:XX-XXXXXXXX-X
Numero de documento
Fecha de actualización: 01-06-2020
Fecha de proceso: 31-07-2020
No se reportan datos para el NUMERO DE DOCUMENTO 2XXXXX1

• DATOS HISTORICOS ADICIONALES

Bajas producidas desde el año 2006 al 01-06-2020

Apellido y Nombre | Tipo Documento | Nro Documento | CUIL
--- | --- | --- | ---
BXXXXXXXXS FXXXL JUAN CARLOS | DU | 2XXXXX1 | 202XXXXX18

Obra Social | CUIL Titular | Tipo Beneficiario | Fecha Alta/Baja | Motivo
--- | --- | --- | --- | ---
1-0880-3 | 20-2XXXXX1-8 | PEQUE�OS CONTRIBUYENTES - MONOTRIBUTISTAS (LEY 25.865) | 01-08-2004/ 31-03-2008 | MONOTRIBUTISTA INF.AFIP
0-0040-6 | 20-2XXXXX1-8 | RELACION DE DEPENDENCIA | 01-05-2013/ 31-12-2013 | POR OPCION
1-2620-5 | 20-2XXXXX1-8 | RELACION DE DEPENDENCIA | 01-12-2010/ 31-10-2013 | POR OPCION
4-0120-1 | 20-2XXXXX1-8 | RELACION DE DEPENDENCIA | 01-09-2013/ 31-08-2016 | SIN DECLARACION JURADA

Cambiar Contrase�a